# py-kin-base

Low level library to interact with the kin blockchain.

**Please note that this library is an internal library to kin-sdk. You should use the higer level [kin-sdk](https://github.com/kinecosystem/kin-core-python/tree/v2-master) when developing for kin**

## Installation
```bash
pip install kin-base
```
